@@ -81,13 +81,11 @@ int main(int argc, char **argv)
     KAboutData aboutData(QStringLiteral("debconf-kde-helper"),
                          i18nc("@title", "Debconf KDE"),
                          QStringLiteral(PROJECT_VERSION),
-                         i18nc("@info", "Debconf frontend for KDE"),
+                         i18nc("@info", "Debconf frontend based on Qt"),
                          KAboutLicense::LicenseKey::LGPL);
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
     QCommandLineOption socketOption(QStringLiteral("socket-path"),
                                     i18nc("@info:shell", "Path to where the socket should be created"),
                                     i18nc("@info:shell value name", "path_to_socket"),
